@@ -4,7 +4,6 @@ import os
 import requests
 import zipfile
 import glob
-import re
 import time
 import datetime
 from dfply import *
@@ -19,7 +18,7 @@ def zip_parser(url=None, survey=None):
     # path = "/tmp/pypeds/" + str(int(time.time())) + "/"  # hacky way to make unique path to extract time
     _today = datetime.datetime.today().strftime('%Y%m%d')
     survey_lower = survey.lower()
-    path = "/tmp/" + str(_today) + str(survey_lower) + "/"  # hacky way to make unique path to extract date and survey
+    path = "/tmp/" + str(_today) + str(survey) + "/"  # hacky way to make unique path to extract date and survey
     file = survey + ".zip"
     
     # naive way to do cacheing - if the path for today exists, dont do anything, if it doesnt, get the data
@@ -38,10 +37,10 @@ def zip_parser(url=None, survey=None):
     file.extractall(path=path)
     # list the csv files for the surveys, most likely get one , but may get to with _rv for revised
     files = glob.glob(path + "*" + survey_lower + "*")
-    # files = [x.lower() for x in files]  ## removed for regex search below
+    files = [x.lower() for x in files]
     # isolate the file name
     if len(files) > 1:
-        raw_file = [s for s in files if re.search('rv|RV', s)] # use regex to search -- 2006 migration
+        raw_file = [s for s in files if 'rv' in s]
         raw_file = str(raw_file[0])  # just in case, take first
     else:
         raw_file = str(files[0])
@@ -57,9 +56,7 @@ def read_survey(path):
         ## encoding option needed for h2017, at least, wasnt needed for IC2013
         survey_file = pd.read_csv(path, encoding='ISO-8859-1')
     except:
-        # need to pass in a list to avoid
-        # ValueError: If using all scalar values, you must pass an index
-        survey_file = pd.DataFrame( [{'path': path}] )
+        survey_file = pd.DataFrame({'path': path})
     # remove the file
     os.remove(path)
     # column names to lower - helps later and assumes a survey varname is historically unique
@@ -74,7 +71,7 @@ def read_survey(path):
 def get_hd(year):
     # assert that year is a int and length 1
     assert isinstance(year, int), "year is not an integer"
-    assert year >= 2002 and year <= 2019, "year must be >=2002 and <= 2019"
+    assert year >= 2002 and year <= 2018, "year must be >=2002 and < 2018"
     # build the SURVEY id
     SURVEY = 'HD' + str(year)
     # build the url
@@ -86,7 +83,7 @@ def get_hd(year):
 def get_ic(year):
     # assert that year is a int and length 1
     assert isinstance(year, int), "year is not an integer"
-    assert year >= 2002 and year <= 2019, "year must be >=2002 and <= 2019"
+    assert year >= 2002 and year <= 2018, "year must be >=2002 and < 2018"
     # build the SURVEY id
     SURVEY = 'IC' + str(year)
     # build the url
@@ -98,7 +95,7 @@ def get_ic(year):
 def get_adm(year):
     # assert that year is a int and length 1
     assert isinstance(year, int), "year is not an integer"
-    assert year >= 2014 and year <= 2018, "year must be >=2014 and <= 2018"
+    assert year >= 2014 and year <= 2018, "year must be >=2014 and < 2018"
     # build the SURVEY id
     SURVEY = 'ADM' + str(year)
     # build the url
@@ -110,7 +107,7 @@ def get_adm(year):
 def get_sfa(year):
     # assert that year is a int and length 1
     assert isinstance(year, int), "year is not an integer"
-    assert year >= 2002 and year <= 2018, "year must be >=2002 and <= 2018"
+    assert year >= 2002 and year <= 2018, "year must be >=2002 and < 2018"
     # build the SURVEY id
     sfa_year = str(year - 1)[2:] + str(year)[2:]
     SURVEY = 'SFA' + str(sfa_year)
@@ -123,7 +120,7 @@ def get_sfa(year):
 def get_efc(year):
     # assert that year is a int and length 1
     assert isinstance(year, int), "year is not an integer"
-    assert year >= 2002 and year <= 2018, "year must be >=2002 and <= 2018"
+    assert year >= 2002 and year <= 2018, "year must be >=2002 and < 2018"
     # build the SURVEY id
     SURVEY = 'EF' + str(year) + "C"
     # build the url
@@ -135,7 +132,7 @@ def get_efc(year):
 def get_icay(year):
     # assert that year is a int and length 1
     assert isinstance(year, int), "year is not an integer"
-    assert year >= 2001 and year <= 2019, "year must be >=2001 and <= 2019"
+    assert year >= 2002 and year <= 2018, "year must be >=2002 and < 2018"
     # build the SURVEY id
     SURVEY = 'IC' + str(year) + "_AY"
     # build the url
@@ -146,7 +143,7 @@ def get_icay(year):
 def get_om(year):
     # assert that year is a int and length 1
     assert isinstance(year, int), "year is not an integer"
-    assert year >= 2015 and year <= 2018, "year must be >=2015 and <= 2018"
+    assert year >= 2015 and year <= 2018, "year must be >=2015 and < 2018"
     # build the SURVEY id
     SURVEY = 'OM' + str(year) 
     # build the url
@@ -157,7 +154,7 @@ def get_om(year):
 def get_efd(year):
     # assert that year is a int and length 1
     assert isinstance(year, int), "year is not an integer"
-    assert year >= 2002 and year <= 2018, "year must be >=2002 and <= 2018"
+    assert year >= 2002 and year <= 2018, "year must be >=2002 and < 2018"
     # build the SURVEY id
     SURVEY = 'EF' + str(year)  + "D"
     # build the url
@@ -168,7 +165,7 @@ def get_efd(year):
 def get_ff1(year):
     # assert that year is a int and length 1
     assert isinstance(year, int), "year is not an integer"
-    assert year >= 2002 and year <= 2018, "year must be >=2002 and <= 2018"
+    assert year >= 2002 and year <= 2018, "year must be >=2002 and < 2018"
     # build the SURVEY id
     ff1_year = str(year - 1)[2:] + str(year)[2:]
     SURVEY = 'F' + str(ff1_year)  + "_F1A"
@@ -180,7 +177,7 @@ def get_ff1(year):
 def get_ff2(year):
     # assert that year is a int and length 1
     assert isinstance(year, int), "year is not an integer"
-    assert year >= 2002 and year <= 2018, "year must be >=2002 and <= 2018"
+    assert year >= 2002 and year <= 2018, "year must be >=2002 and < 2018"
     # build the SURVEY id
     ff2_year = str(year - 1)[2:] + str(year)[2:]
     SURVEY = 'F' + str(ff2_year)  + "_F2"
@@ -192,7 +189,7 @@ def get_ff2(year):
 def get_ca(year):
     # assert that year is a int and length 1
     assert isinstance(year, int), "year is not an integer"
-    assert year >= 2002 and year <= 2019, "year must be >=2002 and <= 2019"
+    assert year >= 2002 and year <= 2018, "year must be >=2002 and < 2018"
     # build the SURVEY id
     SURVEY = 'C' + str(year)  + "_A"
     # build the url
@@ -226,14 +223,14 @@ class HD(object):
         """
         Method to pull one or more IC surveys based on the configured object
 
-        The extract method currently supports back to 2002 and up to 2019.
+        The extract method currently supports back to 2002 and up to 2017.
         """
 
         init_df = pd.DataFrame({'pypeds_init': [True]})
         for year in self.years:
             # assert that year is a int and length 1
             assert isinstance(year, int), "year is not an integer"
-            assert year >= 2002 and year <= 2019, "year must be >=2002 and < 2019"
+            assert year >= 2002 and year <= 2018, "year must be >=2002 and < 2018"
             # build the SURVEY id
             SURVEY = 'HD' + str(year)
             # build the url
@@ -573,7 +570,7 @@ class EFC(object):
 
         return (self.df)
 
-    def transform(self, state=None, line=None, cols=None, regions=None):
+    def transform(self, state=None, line=None, cols=None):
         """
         The transformation method of the data.  
         Arguments activate the transformation, otherwise they are not performed.
@@ -612,19 +609,6 @@ class EFC(object):
                 tmp_f = tmp >> select(cols)
                 tmpdf = tmp_f
         
-        # add the regions info
-        if regions:
-            r = datasets.region_xwalk()
-            r = r >> select(['ipeds_code','name','ipeds_region', 'postal code'])
-            r = r.rename(columns={"ipeds_code": "line", 
-                                  "ipeds_region":"res_region", 
-                                  "postal code":"res_zip",
-                                  "name":"res_name"})
-            r['line'] = r['line'].astype('float64')
-            tmp = tmpdf
-            tmp_f = pd.merge(left=tmp, right=r, on="line", how="left")
-            tmpdf = tmp_f
-        
         # return the data
         self.df = tmpdf
 
